pub struct IssueBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> IssueBuilder<S>
impl<S: State> IssueBuilder<S>
Sourcepub fn build(self) -> Issuewhere
S: IsComplete,
pub fn build(self) -> Issuewhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn active(self, value: bool) -> IssueBuilder<SetActive<S>>where
S::Active: IsUnset,
pub fn active(self, value: bool) -> IssueBuilder<SetActive<S>>where
S::Active: IsUnset,
Required.
Whether the condition behind this issue is still ongoing. Set to
false when the source reports the condition has cleared.
Sourcepub fn created_at(self, value: Timestamp) -> IssueBuilder<SetCreatedAt<S>>where
S::CreatedAt: IsUnset,
pub fn created_at(self, value: Timestamp) -> IssueBuilder<SetCreatedAt<S>>where
S::CreatedAt: IsUnset,
Required.
When this issue was first created.
Sourcepub fn description(self, value: String) -> IssueBuilder<SetDescription<S>>where
S::Description: IsUnset,
pub fn description(self, value: String) -> IssueBuilder<SetDescription<S>>where
S::Description: IsUnset,
Sourcepub fn maybe_description(
self,
value: Option<String>,
) -> IssueBuilder<SetDescription<S>>where
S::Description: IsUnset,
pub fn maybe_description(
self,
value: Option<String>,
) -> IssueBuilder<SetDescription<S>>where
S::Description: IsUnset,
Sourcepub fn device_id(self, value: Uuid) -> IssueBuilder<SetDeviceId<S>>where
S::DeviceId: IsUnset,
pub fn device_id(self, value: Uuid) -> IssueBuilder<SetDeviceId<S>>where
S::DeviceId: IsUnset,
Sourcepub fn maybe_device_id(
self,
value: Option<Uuid>,
) -> IssueBuilder<SetDeviceId<S>>where
S::DeviceId: IsUnset,
pub fn maybe_device_id(
self,
value: Option<Uuid>,
) -> IssueBuilder<SetDeviceId<S>>where
S::DeviceId: IsUnset,
Sourcepub fn first_seen(self, value: Timestamp) -> IssueBuilder<SetFirstSeen<S>>where
S::FirstSeen: IsUnset,
pub fn first_seen(self, value: Timestamp) -> IssueBuilder<SetFirstSeen<S>>where
S::FirstSeen: IsUnset,
Required.
When this issue was first reported.
Sourcepub fn id(self, value: Uuid) -> IssueBuilder<SetId<S>>where
S::Id: IsUnset,
pub fn id(self, value: Uuid) -> IssueBuilder<SetId<S>>where
S::Id: IsUnset,
Required.
Unique identifier for this issue.
Sourcepub fn last_seen(self, value: Timestamp) -> IssueBuilder<SetLastSeen<S>>where
S::LastSeen: IsUnset,
pub fn last_seen(self, value: Timestamp) -> IssueBuilder<SetLastSeen<S>>where
S::LastSeen: IsUnset,
Required.
When this issue was most recently reported or updated.
Sourcepub fn message(self, value: String) -> IssueBuilder<SetMessage<S>>where
S::Message: IsUnset,
pub fn message(self, value: String) -> IssueBuilder<SetMessage<S>>where
S::Message: IsUnset,
Required.
The full body text describing the issue.
Sourcepub fn ref_(self, value: String) -> IssueBuilder<SetRef<S>>where
S::Ref: IsUnset,
pub fn ref_(self, value: String) -> IssueBuilder<SetRef<S>>where
S::Ref: IsUnset,
Required.
A caller-chosen identifier for this issue within its source. The
same (source, ref) pair reported again updates this issue instead
of creating a new one.
Sourcepub fn resolved_at(self, value: Timestamp) -> IssueBuilder<SetResolvedAt<S>>where
S::ResolvedAt: IsUnset,
pub fn resolved_at(self, value: Timestamp) -> IssueBuilder<SetResolvedAt<S>>where
S::ResolvedAt: IsUnset,
Sourcepub fn maybe_resolved_at(
self,
value: Option<Timestamp>,
) -> IssueBuilder<SetResolvedAt<S>>where
S::ResolvedAt: IsUnset,
pub fn maybe_resolved_at(
self,
value: Option<Timestamp>,
) -> IssueBuilder<SetResolvedAt<S>>where
S::ResolvedAt: IsUnset,
Sourcepub fn resolved_by(self, value: String) -> IssueBuilder<SetResolvedBy<S>>where
S::ResolvedBy: IsUnset,
pub fn resolved_by(self, value: String) -> IssueBuilder<SetResolvedBy<S>>where
S::ResolvedBy: IsUnset,
Sourcepub fn maybe_resolved_by(
self,
value: Option<String>,
) -> IssueBuilder<SetResolvedBy<S>>where
S::ResolvedBy: IsUnset,
pub fn maybe_resolved_by(
self,
value: Option<String>,
) -> IssueBuilder<SetResolvedBy<S>>where
S::ResolvedBy: IsUnset,
Sourcepub fn resolved_reason(
self,
value: String,
) -> IssueBuilder<SetResolvedReason<S>>where
S::ResolvedReason: IsUnset,
pub fn resolved_reason(
self,
value: String,
) -> IssueBuilder<SetResolvedReason<S>>where
S::ResolvedReason: IsUnset,
Sourcepub fn maybe_resolved_reason(
self,
value: Option<String>,
) -> IssueBuilder<SetResolvedReason<S>>where
S::ResolvedReason: IsUnset,
pub fn maybe_resolved_reason(
self,
value: Option<String>,
) -> IssueBuilder<SetResolvedReason<S>>where
S::ResolvedReason: IsUnset,
Sourcepub fn server_group_id(self, value: Uuid) -> IssueBuilder<SetServerGroupId<S>>where
S::ServerGroupId: IsUnset,
pub fn server_group_id(self, value: Uuid) -> IssueBuilder<SetServerGroupId<S>>where
S::ServerGroupId: IsUnset,
Optional (Some / Option setters).
The server group this issue is attached to, for a control-plane issue
(e.g. backup corruption, a failed preflight check) that isn’t tied to
any single server. None for an ordinary server-scoped issue.
Group-scoped issues are always considered even if an individual
server in the group has monitoring turned off.
Sourcepub fn maybe_server_group_id(
self,
value: Option<Uuid>,
) -> IssueBuilder<SetServerGroupId<S>>where
S::ServerGroupId: IsUnset,
pub fn maybe_server_group_id(
self,
value: Option<Uuid>,
) -> IssueBuilder<SetServerGroupId<S>>where
S::ServerGroupId: IsUnset,
Optional (Some / Option setters).
The server group this issue is attached to, for a control-plane issue
(e.g. backup corruption, a failed preflight check) that isn’t tied to
any single server. None for an ordinary server-scoped issue.
Group-scoped issues are always considered even if an individual
server in the group has monitoring turned off.
Sourcepub fn server_id(self, value: Uuid) -> IssueBuilder<SetServerId<S>>where
S::ServerId: IsUnset,
pub fn server_id(self, value: Uuid) -> IssueBuilder<SetServerId<S>>where
S::ServerId: IsUnset,
Sourcepub fn maybe_server_id(
self,
value: Option<Uuid>,
) -> IssueBuilder<SetServerId<S>>where
S::ServerId: IsUnset,
pub fn maybe_server_id(
self,
value: Option<Uuid>,
) -> IssueBuilder<SetServerId<S>>where
S::ServerId: IsUnset,
Sourcepub fn severity(self, value: Severity) -> IssueBuilder<SetSeverity<S>>where
S::Severity: IsUnset,
pub fn severity(self, value: Severity) -> IssueBuilder<SetSeverity<S>>where
S::Severity: IsUnset,
Required.
The issue’s current severity.
Sourcepub fn snoozed_until(self, value: Timestamp) -> IssueBuilder<SetSnoozedUntil<S>>where
S::SnoozedUntil: IsUnset,
pub fn snoozed_until(self, value: Timestamp) -> IssueBuilder<SetSnoozedUntil<S>>where
S::SnoozedUntil: IsUnset,
Sourcepub fn maybe_snoozed_until(
self,
value: Option<Timestamp>,
) -> IssueBuilder<SetSnoozedUntil<S>>where
S::SnoozedUntil: IsUnset,
pub fn maybe_snoozed_until(
self,
value: Option<Timestamp>,
) -> IssueBuilder<SetSnoozedUntil<S>>where
S::SnoozedUntil: IsUnset,
Sourcepub fn source(self, value: String) -> IssueBuilder<SetSource<S>>where
S::Source: IsUnset,
pub fn source(self, value: String) -> IssueBuilder<SetSource<S>>where
S::Source: IsUnset,
Required.
Identifies what raised this issue — a healthcheck, a backup pipeline,
an operator, etc. Used together with ref to detect repeat reports
of the same underlying problem.
Sourcepub fn updated_at(self, value: Timestamp) -> IssueBuilder<SetUpdatedAt<S>>where
S::UpdatedAt: IsUnset,
pub fn updated_at(self, value: Timestamp) -> IssueBuilder<SetUpdatedAt<S>>where
S::UpdatedAt: IsUnset,
Required.
When this issue was last modified.