#[non_exhaustive]pub struct ApplicationEntitlements {
pub certificates: Vec<HeldCertificate>,
pub domains: Vec<String>,
pub may_manage_dns: bool,
pub may_manage_tls: bool,
pub paused: bool,
pub registered_names: Vec<String>,
pub type_: ApplicationType,
}Expand description
What one application on the asking machine may act on.
JSON schema
{
"description": "What one application on the asking machine may act on.",
"type": "object",
"required": [
"certificates",
"domains",
"may_manage_dns",
"may_manage_tls",
"paused",
"registered_names",
"type"
],
"properties": {
"certificates": {
"description": "The certificates Canopy holds for it.",
"type": "array",
"items": {
"$ref": "#/components/schemas/HeldCertificate"
}
},
"domains": {
"description": "The domains its group controls.",
"type": "array",
"items": {
"type": "string"
}
},
"may_manage_dns": {
"description": "Whether this application may manage its own DNS records.",
"type": "boolean"
},
"may_manage_tls": {
"description": "Whether this application may obtain its own TLS certificates.",
"type": "boolean"
},
"paused": {
"description": "Whether Canopy is currently making no new changes on its behalf.",
"type": "boolean"
},
"registered_names": {
"description": "The names it has registered addresses for.",
"type": "array",
"items": {
"type": "string"
}
},
"type": {
"description": "The type of application these entitlements belong to.\n\nA reporter correlates an entry to a workload it runs by the machine it\nasked as and this type. Canopy's own identifier for the application is\ninternal and never on the wire.",
"$ref": "#/components/schemas/ApplicationType"
}
}
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.certificates: Vec<HeldCertificate>The certificates Canopy holds for it.
domains: Vec<String>The domains its group controls.
may_manage_dns: boolWhether this application may manage its own DNS records.
may_manage_tls: boolWhether this application may obtain its own TLS certificates.
paused: boolWhether Canopy is currently making no new changes on its behalf.
registered_names: Vec<String>The names it has registered addresses for.
type_: ApplicationTypeThe type of application these entitlements belong to.
A reporter correlates an entry to a workload it runs by the machine it asked as and this type. Canopy’s own identifier for the application is internal and never on the wire.
Implementations
Sourceimpl ApplicationEntitlements
impl ApplicationEntitlements
Sourcepub fn builder() -> ApplicationEntitlementsBuilder
pub fn builder() -> ApplicationEntitlementsBuilder
Create an instance of ApplicationEntitlements using the builder syntax